@@ -142,7 +142,12 @@ class CRFClassifier(LazaroClassifier):
             )
         )
         crf.tagger = pycrfsuite.Tagger()
-        crf.tagger.open(path_to_model.as_posix())
+        try:
+            crf.tagger.open(path_to_model.as_posix())
+        except:
+            print(
+                "CRF model file does not exist. Extended installation needed! Please install the extended version of pylazaro (See https://pylazaro.readthedocs.io/en/latest/install.html)"
+            )
         return crf
 
     @spacy_model.default
